```{include} ../README.md

```

```{toctree}
:caption: Getting Started
:maxdepth: 2

installation
dummy_vs_real
changelog
```

```{toctree}
:caption: Tools & Usage
:maxdepth: 2

tools
```

```{toctree}
:caption: API Documentation
:maxdepth: 2

autoapi/index
```
